<?php

/***************************************************************************************
 *                                                                                     *
 * This file is part of the XPertMailer package (http://xpertmailer.sourceforge.net/)  *
 *                                                                                     *
 * XPertMailer is free software; you can redistribute it and/or modify it under the    *
 * terms of the GNU General Public License as published by the Free Software           *
 * Foundation; either version 2 of the License, or (at your option) any later version. *
 *                                                                                     *
 * XPertMailer is distributed in the hope that it will be useful, but WITHOUT ANY      *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A     *
 * PARTICULAR PURPOSE.  See the GNU General Public License for more details.           *
 *                                                                                     *
 * You should have received a copy of the GNU General Public License along with        *
 * XPertMailer; if not, write to the Free Software Foundation, Inc., 51 Franklin St,   *
 * Fifth Floor, Boston, MA  02110-1301  USA                                            *
 *                                                                                     *
 * XPertMailer php functions class. Sends e-mail message in MIME type format.          *
 * Copyright (C) 2006  Tanase Laurentiu Iulian                                         *
 *                                                                                     *
 ***************************************************************************************/

set_time_limit(0);

// optionaly, you can disable display errors
error_reporting(false); // from php (generally)
define('PRINT_ERROR', false); // from XPertMailer class

// path to XPertMailer class file
require_once '../XPertMailer.php';

/**
 * - send to multiple e-mail addresses - text/html format
 *   with two HTML embedded images and two attachment files
 * - set authentication and socket connection via relay TSL/SSL
 * - set Cc and Bcc values (sending to additional e-mail addresses)
 * ------------------------------------------------------
 */

// optionaly, you can use an relay host name, if fail, send directly to the client
$mail = new XPertMailer(SMTP_RELAY_CLIENT, 'relay-host-name.com');

// set authentication username and password for relay host and auth type AUTH_DETECT (default)
// optionaly, you can transfer data via TSL/SSL connection at relay port 465, default are 25
// (for this you must have OpenSSL module enable in your PHP configuration)
$mail->auth('username', 'password', AUTH_DETECT, SSL_TRUE, 465);

// optionaly, set the default port number value for SMTP server socket connections, default are 25
// here for client 2'nd connection (if fail relay)
$mail->port(25);

// optionaly, set time out for SMTP server socket connections (in secounds), default are 30
$mail->timeout(10);

// set priority high, default it is normal
$mail->priority(P_HIGH);

// set from e-mail address and optionaly from name
// attention, if you are using a relay server with authentication then you must write the true From e-mail address, 
// if not, normaly, this will be replaced by the relay server with authentication username (at) relay host name
$mail->from('username@relay-host-name.com', 'My Name');

// set each header name and value
$header['Cc'] = 'user1@example1.com, anotheruser1@example2.com';
$header['Bcc'] = 'user2@example3.com, anotheruser2@example4.com';
$header['Reply-To'] = 'reply@domain.com';
$header['X-Whatever'] = 'description';

// set additional header informations
$mail->headers($header);

// set HTML embedded images name and optionaly you can rename them
// if the file is not in this directory, write the path name (/path/name.image_extension)
// Attention: do not include path name in the rename file like /path/rename.gif, put only rename.gif
$imgs[] = 'image1.jpg';
$imgs['rename.gif'] = 'image2.gif';

// attach HTML embedded images
$mail->attach($imgs, ATTACH_HTML_IMG);

// set attachment files name and optional you can rename them
// if the file is not in this directory, write the path name (/path/name.file_extension)
$file['new.zip'] = 'archive1.zip';
$file[] = 'archive2.tar.gz';

// attach files
$mail->attach($file, ATTACH_FILE);

// set html value
// Attention: do not include image path name in HTML source like <img src="/path/name.jpg">, put only <img src="name.jpg">
$html = '<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0 Transitional//EN\">
<html>
<body>
<img src="image1.jpg" border="0"><br>
<b><u><i>next image</i></u></b> :-)<br>
<img src="rename.gif" border="2"><br>
<font color="red">message html red here</font>
</body>
</html>';

// send to multiple e-mail addresses and optionaly you can set charset value (here UTF-8, by default is ISO-8859-1)
// as you can see, the text/plain message is required because not all mail clients can currently support HTML messages
$send = $mail->send('touser@domain1.com, toanotheruser@domain2.com', 'subject here', 'text version'.CRLF.'new line', $html, 'UTF-8');

// compare the result and print a message
echo $send ? "Done." : "Error.";

// some useful for debugging
echo "<br>Server response: ".$mail->response;

?>